@@ -6,6 +6,7 @@ using namespace std;
 // Forward function declarations
 QString baseDir();
 void initLogging (const QString &userIni);
+extern QString strLogfile;
 
 MainWindow::MainWindow(QObject *parent /*= 0*/)
 : QObject(parent)
@@ -14,10 +15,22 @@ MainWindow::MainWindow(QObject *parent /*= 0*/)
 , oContacts (this)
 , oInbox (gvApi, this)
 , checkCounter (0)
-, consoleThread (NULL)
+, client (NULL)
 {
     qRegisterMetaType<ContactInfo>("ContactInfo");
 
+    QTimer::singleShot (10, this, SLOT(init()));
+}//MainWindow::MainWindow
+
+void
+MainWindow::setStatus(const QString &strText, int /*timeout = 3000*/)
+{
+    Q_DEBUG(strText);
+}//MainWindow::setStatus
+
+void
+MainWindow::init()
+{
     // Status from contacts object
     QObject::connect (&oContacts, SIGNAL (status   (const QString &, int)),
                        this     , SLOT   (setStatus(const QString &, int)));
@@ -38,15 +51,6 @@ MainWindow::MainWindow(QObject *parent /*= 0*/)
         return;
     }
 
-    consoleThread = new ConsoleThread(this);
-    if (NULL == consoleThread) {
-        qApp->quit();
-        return;
-    }
-
-    QObject::connect (consoleThread, SIGNAL(finished()), this, SLOT(getOut()));
-    consoleThread->start ();
-
     QDateTime dtNow = QDateTime::currentDateTime ();
     QDateTime dtTomorrow = dtNow.addDays (1);
     dtTomorrow.setTime (QTime(0, 0));
@@ -55,14 +59,20 @@ MainWindow::MainWindow(QObject *parent /*= 0*/)
     QTimer::singleShot (sec * 1000, this, SLOT(dailyTimeout()));
     Q_DEBUG(QString("Daily timer first shot after %1 seconds").arg (sec));
 
-    QTimer::singleShot (100, this, SLOT(doWork ()));
-}//MainWindow::MainWindow
+    client = new QGVNotifyProxyIface("net.yuvraaj.qgvnotify.control", "/",
+                                     QDBusConnection::sessionBus(), 0);
+    if (NULL == client) {
+        Q_CRIT("Failed to initialize DBus client");
+        getOut ();
+        return;
+    }
+    connect(client, SIGNAL(CommandForClient(const QString &)),
+            this  , SLOT(onCommandForClient(const QString &)));
 
-void
-MainWindow::setStatus(const QString &strText, int /*timeout = 3000*/)
-{
-    Q_DEBUG(strText);
-}//MainWindow::setStatus
+    onCommandForClient("getUser");
+
+    doWork ();
+}//MainWindow::init
 
 void
 MainWindow::doWork ()
@@ -87,7 +97,6 @@ bool
 MainWindow::checkParams ()
 {
     bool rv = false, bUseDefaultIni = false;
-    QString strIni;
     QStringList args = qApp->arguments ();
     if (args.length () < 2) {
         qWarning ("No ini file specified, using default");
@@ -459,3 +468,21 @@ MainWindow::getOut()
     Q_DEBUG("quit!!");
     qApp->quit ();
 }//MainWindow::getOut
+
+void
+MainWindow::onCommandForClient(const QString &command)
+{
+    Q_DEBUG(QString("command = %1").arg(command));
+
+    if (NULL == client) {
+        Q_WARN("client is NULL");
+        return;
+    }
+
+    if (command == "getUser") {
+        client->ReportUser(strUser, strIni, strLogfile,
+                           qApp->applicationPid());
+    } else if (command == "quitAll") {
+        getOut ();
+    }
+}//MainWindow::onCommandForClient
