@@ -39,7 +39,7 @@ MainWindow::initLogging ()
                         this     , SLOT(onCleanupLogsArray()));
     Q_ASSERT(rv); Q_UNUSED(rv);
 
-    Q_DEBUG("Using qgvdial version 0.3.1003");
+    Q_DEBUG("Using qgvdial version 0.3.1023");
 }//MainWindow::initLogging
 
 /** Log information to console and to log file
@@ -219,7 +219,7 @@ MainWindow::onGetLogLocation(bool success, const QByteArray &response,
         QDomElement appVerTag = doc.createElement("Version");
         paramsTag.appendChild(appVerTag);
 
-        QDomText appVerText = doc.createTextNode("0.3.1003");
+        QDomText appVerText = doc.createTextNode("0.3.1023");
         appVerTag.appendChild(appVerText);
 
         QDomElement osVerTag = doc.createElement("OsVer");
@@ -287,7 +287,7 @@ MainWindow::onLogPosted(bool success, const QByteArray &response,
         QDateTime dt = token->inParams["date"].toDateTime();
         QString body = QString("Logs captured at %1 \n")
                                 .arg (dt.toUTC ().toString (Qt::ISODate));
-        body += "qgvdial version = 0.3.1003 \n";
+        body += "qgvdial version = 0.3.1023 \n";
         body += QString("OS: %1 \n").arg(osd.getOSDetails());
         body += QString("Logs are in %1 \n").arg(strReply);
         url.addQueryItem ("body", body);
@@ -303,4 +303,10 @@ MainWindow::onLogPosted(bool success, const QByteArray &response,
     if (token) {
         delete token;
     }
+
+    if (nwMgr) {
+        // We're done using the NW mgr. get rid of it.
+        nwMgr->deleteLater ();
+        nwMgr = NULL;
+    }
 }//MainWindow::onLogPosted
