@@ -33,6 +33,7 @@ MainWindow::MainWindow (QWidget *parent)
 , pSystray (NULL)
 , oContacts (this)
 , oInbox (gvApi, this)
+, bBeginPlayAfterLoad (false)
 , vmailPlayer (NULL)
 , nwMgr (NULL)
 , statusTimer (this)
@@ -85,8 +86,8 @@ MainWindow::MainWindow (QWidget *parent)
         pSystray->show ();
     }
 
-    rv = connect (qApp, SIGNAL (messageReceived (const QString &)),
-                  this, SLOT   (messageReceived (const QString &)));
+    rv = connect (qApp, SIGNAL (messageReceived(const QString &)),
+                  this, SLOT   (messageReceived(const QString &)));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
 
@@ -96,7 +97,7 @@ MainWindow::MainWindow (QWidget *parent)
     if (!rv) { exit(1); }
 
     // Schedule the init a bit later so that the app.exec() can begin executing
-    QTimer::singleShot (100, this, SLOT (init()));
+    QTimer::singleShot (10, this, SLOT (init()));
 }//MainWindow::MainWindow
 
 MainWindow::~MainWindow ()
@@ -406,6 +407,9 @@ MainWindow::initQML ()
     ctx->setContextProperty ("g_wMul", wMul);
     ctx->setContextProperty ("g_fontMul", fontMul);
 
+    ctx->setContextProperty ("g_IsMobilePlatform",
+                             MOBILE_OS ? !bTempFalse : bTempFalse);
+
     // Initialize the QML view
     this->setSource (QUrl(osd.getMainQML()));
 
